package com.zhyc.module.dairyProducts.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zhyc.module.dairyProducts.mapper.XzParityCorrectionMapper;
import com.zhyc.module.dairyProducts.domain.XzParityCorrection;
import com.zhyc.module.dairyProducts.service.IXzParityCorrectionService;

/**
 * 胎次校正Service业务层处理
 *
 * @author ruoyi
 * @date 2025-08-24
 */
@Service
public class XzParityCorrectionServiceImpl implements IXzParityCorrectionService
{
    @Autowired
    private XzParityCorrectionMapper xzParityCorrectionMapper;

    /**
     * 查询胎次校正
     *
     * @param id 胎次校正主键
     * @return 胎次校正
     */
    @Override
    public XzParityCorrection selectXzParityCorrectionById(Long id)
    {
        return xzParityCorrectionMapper.selectXzParityCorrectionById(id);
    }

    /**
     * 查询胎次校正列表
     *
     * @param xzParityCorrection 胎次校正
     * @return 胎次校正
     */
    @Override
    public List<XzParityCorrection> selectXzParityCorrectionList(XzParityCorrection xzParityCorrection)
    {
        return xzParityCorrectionMapper.selectXzParityCorrectionList(xzParityCorrection);
    }

    /**
     * 新增胎次校正
     *
     * @param xzParityCorrection 胎次校正
     * @return 结果
     */
    @Override
    public int insertXzParityCorrection(XzParityCorrection xzParityCorrection)
    {
        return xzParityCorrectionMapper.insertXzParityCorrection(xzParityCorrection);
    }

    /**
     * 修改胎次校正
     *
     * @param xzParityCorrection 胎次校正
     * @return 结果
     */
    @Override
    public int updateXzParityCorrection(XzParityCorrection xzParityCorrection)
    {
        return xzParityCorrectionMapper.updateXzParityCorrection(xzParityCorrection);
    }

    /**
     * 批量删除胎次校正
     *
     * @param ids 需要删除的胎次校正主键
     * @return 结果
     */
    @Override
    public int deleteXzParityCorrectionByIds(Long[] ids)
    {
        return xzParityCorrectionMapper.deleteXzParityCorrectionByIds(ids);
    }

    /**
     * 删除胎次校正信息
     *
     * @param id 胎次校正主键
     * @return 结果
     */
    @Override
    public int deleteXzParityCorrectionById(Long id)
    {
        return xzParityCorrectionMapper.deleteXzParityCorrectionById(id);
    }
}
